@@ -10,13 +10,13 @@ class WeakNetworkConfig(object):
         2、为设备配置弱网配置
     """
     # ios切换网络app bundle_id
-    IOS_APP_BUNDLE_ID = "com.yy.net.test"
+    IOS_APP_BUNDLE_ID = "com.yy.net"
     # atc 接口
     ATC_AUTH_URI = "/api/v1/auth/{}/"
     ATC_SHAPE_URI = "/api/v1/shape/{}/"
 
     def __init__(self, atc_host="http://172.29.182.90:8000", stf_url=None, sft_token=None, wifi_name="yy_net",
-                 wifi_password="", platform="ios"):
+                 wifi_password=""):
         """
             :param atc_host: atc服务地址
             :param stf_url: sft服务器地址
@@ -28,7 +28,6 @@ class WeakNetworkConfig(object):
         self._atc_host = atc_host
         self._wifi_name = wifi_name
         self._wifi_password = wifi_password
-        self.platform = platform
         self.device_ip = None
         self.device = None
         self._stf = STFServer(url=stf_url, token=sft_token)
@@ -51,12 +50,12 @@ class WeakNetworkConfig(object):
             连接弱网WIFI热点
         """
         self.platform = platform
+        self.serail = device_serial
         if self.platform == 'ios':
             self._get_device_info(device_serial, platform=platform)
             return self._connect_ios()
         else:
-            return self._connect_android(device_serial)
-
+            return self._connect_android()
 
     def disconnect_wifi(self):
         """
@@ -67,9 +66,8 @@ class WeakNetworkConfig(object):
         else:
             return self._disconnect_android()
 
-    def _connect_android(self, device_serial):
-        self.serail = device_serial
-        ret = self._stf.toggleAndroidWifi(device_serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
+    def _connect_android(self):
+        ret = self._stf.toggleAndroidWifi(self.serail, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
         ip = ret.get("ip", None)
         if str(ip).startswith("192.168.0"):
             return True
@@ -107,6 +105,9 @@ class WeakNetworkConfig(object):
             raise Exception(f"device_serial is None")
 
     def _disconnect_ios(self):
+        self.bundle_id = self._stf.find_ios_bundle_id(self.serail, WeakNetworkConfig.IOS_APP_BUNDLE_ID)
+        if self.bundle_id is None:
+            raise Exception('No iOS app bundle:{} found'.format(WeakNetworkConfig.IOS_APP_BUNDLE_ID))
         self._stf.stop_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID)
         self._stf.launch_ios_app(self.device['wda_url'], WeakNetworkConfig.IOS_APP_BUNDLE_ID, args=['disconnect'])
         return True
